@@ -327,16 +327,15 @@ void gcpAtom::Add(GtkWidget* w)
 		gtk_text_tag_table_add(TextTagTable, tag);
 		g_object_unref((GObject*)tag);
 	}
-	double x, y, xc, yc;
+	double x, y, xc = 0., yc;
 	m_width =  m_height = 2.0 * pData->Padding;
 	GetCoords(&x, &y);
 	x *= pData->ZoomFactor;
 	y *= pData->ZoomFactor;
 	double dFontHeight = pData->View->GetFontHeight();
-	char * szFontName = pData->View->GetFontName();
 	GnomeCanvasItem *item;
 	GnomeCanvasGroup *group, *chgp;
-	int index;
+	int index = 0;
 	char *hs;
 	PangoContext* pc = pData->View->GetPangoContext();
 	group = GNOME_CANVAS_GROUP(gnome_canvas_item_new(pData->Group, gnome_canvas_group_ext_get_type(), NULL));
@@ -559,7 +558,7 @@ void gcpAtom::Update(GtkWidget* w)
 {
 	if (!w) return;
 	gcpWidgetData* pData = (gcpWidgetData*)g_object_get_data(G_OBJECT(w), "data");
-	double x, y, xc, yc;
+	double x, y, xc = 0., yc;
 	GetCoords(&x, &y);
 	x *= pData->ZoomFactor;
 	y *= pData->ZoomFactor;
@@ -1095,6 +1094,7 @@ void gcpAtom::SetSelected(GtkWidget* w, int state)
 		case SelStateSelected: chargecolor = color = SelectColor; break;
 		case SelStateUpdating: chargecolor = color = AddColor; break;
 		case SelStateErasing: chargecolor = color = DeleteColor; break;
+		default: color = "white"; chargecolor = "black"; break;
 	}
 	g_object_set (G_OBJECT(g_object_get_data(G_OBJECT(group), "rect")),
 				"fill_color", color, NULL);
@@ -1113,7 +1113,7 @@ bool gcpAtom::AcceptNewBonds(int nb)
 		return Element::GetMaxBonds(m_Z) >= (GetTotalBondsNumber() + GetChildrenNumber () + nb);
 	map<string, Object*>::iterator i;
 	gcpElectron* electron = (gcpElectron*) GetFirstChild (i);
-	int nel = 0;
+	unsigned nel = 0;
 	while (electron){ 
 		if (electron->IsPair ())
 			nel += 2;
@@ -1146,7 +1146,7 @@ void gcpAtom::BuildItems (gcpWidgetData* pData)
 	if ((GetZ() != 6) || (GetBondsNumber() == 0))
 	{
 		int sw, hw = 0, nw = 0;
-		int index;
+		int index = 0;
 		char *hs;
 		gtk_text_buffer_get_bounds(m_buf, &start, &end);
 		gtk_text_buffer_delete(m_buf, &start, &end);
@@ -1266,7 +1266,7 @@ bool gcpAtom::HasImplicitElectronPairs ()
 		}
 		return (m_nlp > nexplp);
 	}
-	int nel = 0;
+	unsigned nel = 0;
 	while (electron){ 
 		if (electron->IsPair ())
 			nel += 2;
@@ -1283,7 +1283,7 @@ bool gcpAtom::MayHaveImplicitUnpairedElectrons ()
 {
 	map<string, Object*>::iterator i;
 	gcpElectron* electron = (gcpElectron*) GetFirstChild (i);
-	int nel = 0;
+	unsigned nel = 0;
 	while (electron){ 
 		if (electron->IsPair ())
 			nel += 2;
@@ -1476,7 +1476,7 @@ bool gcpAtom::Load (xmlNodePtr node)
 }
 	
 bool gcpAtom::AcceptCharge (int charge) {
-	int nb = GetTotalBondsNumber (), ne = 0;
+	unsigned nb = GetTotalBondsNumber (), ne = 0;
 	map<string, Object*>::iterator i;
 	gcpElectron* electron = (gcpElectron*) GetFirstChild (i);
 	while (electron){ 
