@@ -190,7 +190,7 @@ bool gcpDocument::ImportOB(OBMol& Mol)
 	m_title = g_strdup(Mol.GetTitle());
 	OBAtom *atom;
 	gcpAtom* pAtom;
-	double xmin, xmax, ymin, ymax, x, y;
+	double xmin = 0., xmax = 0., ymin = 0., ymax = 0., x, y;
 	bool valid = false;
 	vector<OBNodeBase*>::iterator i;
 	for (atom = Mol.BeginAtom(i); atom; atom = Mol.NextAtom(i))
@@ -296,7 +296,6 @@ void gcpDocument::ExportOB()
 		Mol.AddAtom(Atom);
 		Atom.Clear();
 	}
-	OBAtom* pAtom;
 	BuildBondList(BondList, this);
 	list<gcpBond*>::iterator j;
 	int start, end, order, flag;
@@ -362,7 +361,6 @@ void gcpDocument::AddAtom(gcpAtom* pAtom)
 	char id[8];
 	const gchar *Id;
 	Id = pAtom->GetId();
-	Object* pObject = GetDescendant(Id);
 	if (Id == NULL) 
 	{
 		id[0] = 'a';
@@ -376,7 +374,6 @@ void gcpDocument::AddAtom(gcpAtom* pAtom)
 	if (m_bIsLoading)
 		return;
 //	AddObject(pAtom);
-	int i0 = 1;
 	gcpMolecule* mol = new gcpMolecule();
 	i = 1;
 	id[0] = 'm';
@@ -395,7 +392,6 @@ void gcpDocument::AddFragment(gcpFragment* pFragment)
 	char id[8];
 	const gchar *Id;
 	Id = pFragment->GetId();
-	Object* pObject = GetDescendant(Id);
 	if (Id == NULL) 
 	{
 		id[0] = 'f';
@@ -411,7 +407,6 @@ void gcpDocument::AddFragment(gcpFragment* pFragment)
 //	AddObject(pFragment);
 	if (!pFragment->GetMolecule())
 	{
-		int i0 = 1;
 		gcpMolecule* mol = new gcpMolecule();
 		i = 1;
 		id[0] = 'm';
@@ -432,7 +427,6 @@ void gcpDocument::AddBond(gcpBond* pBond)
 	char id[8];
 	const gchar *Id;
 	Id = pBond->GetId();
-	Object* pObject = GetDescendant(Id);
 	if (Id == NULL)
 	{
 		id[0] = 'b';
@@ -629,7 +623,6 @@ xmlDocPtr gcpDocument::BuildXMLTree()
 	xml->children =  xmlNewDocNode(xml, NULL, (xmlChar*)"chemistry", NULL);
 	ns = xmlNewNs (xml->children, (xmlChar*) "http://www.nongnu.org/gchempaint", (xmlChar*) "gcp");
 	xmlSetNs (xml->children, ns);
-	SaveId(node);
 	if (!g_date_valid(&CreationDate))
 		g_date_set_time(&CreationDate, time(NULL));
 	g_date_set_time(&RevisionDate, time(NULL));
@@ -1093,6 +1086,8 @@ gcpOperation* gcpDocument::GetNewOperation(gcpOperationType type)
 			return m_pCurOp = new gcpDeleteOperation(this);
 		case GCP_MODIFY_OPERATION:
 			return m_pCurOp = new gcpModifyOperation(this);
+		default:
+			return NULL;
 	}
 }
 
