@@ -263,7 +263,6 @@ bool gcpFragment::OnEndUserAction(GtkTextBuffer *textbuffer)
 	if (m_InsertOffset < 0) return true;
 	if (m_buf != textbuffer) return false;
 	GtkTextIter start, end;
-	char c;
 	gcpDocument* pDoc = (gcpDocument*)GetDocument();
 	gcpApplication* pApp = pDoc->GetApplication();
 	gcpTool* FragmentTool = pApp->GetTool("Fragment");
@@ -458,6 +457,7 @@ void gcpFragment::SetSelected(GtkWidget* w, int state)
 		case SelStateSelected: chargecolor = color = SelectColor; break;
 		case SelStateUpdating: chargecolor = color = AddColor; break;
 		case SelStateErasing: chargecolor = color = DeleteColor; break;
+		default: color = "white"; chargecolor = "black"; break;
 	}
 	g_object_set(G_OBJECT(g_object_get_data(G_OBJECT(group), "rect")),
 				"fill_color", color, NULL);
@@ -671,7 +671,6 @@ bool gcpFragment::SavePortion(xmlDocPtr xml, xmlNodePtr node, GtkTextIter& start
 	int charge;
 	GtkTextTag* tag = gtk_text_tag_table_lookup(TextTagTable, "superscript");
 	cur = start;
-	bool result;
 	while (!gtk_text_iter_equal(&cur, &end))
 	{
 		if (!gtk_text_iter_forward_to_tag_toggle(&cur, tag) || (gtk_text_iter_compare(&cur, &end) > 0))
@@ -727,7 +726,6 @@ xmlNodePtr gcpFragment::SaveSelection(xmlDocPtr xml)
 	int charge;
 	GtkTextTag* tag = gtk_text_tag_table_lookup(TextTagTable, "superscript");
 	cur = start;
-	bool result;
 	while (!gtk_text_iter_equal(&cur, &end))
 	{
 		if (!gtk_text_iter_forward_to_tag_toggle(&cur, tag) || (gtk_text_iter_compare(&cur, &end) > 0))
@@ -966,7 +964,7 @@ void gcpFragment::AnalContent(GtkTextIter& start, GtkTextIter& end)
 						buf = g_strdup_printf("%d%c", abs(charge),(charge > 0)? '+': '-');
 					else if (charge == 1) buf = g_strdup_printf("+");
 					else if (charge == -1) buf = g_strdup_printf("-");
-					else buf = g_strdup_printf("");
+					else buf = g_strdup("");
 					length -= strlen(buf);
 					gtk_text_buffer_get_iter_at_offset(m_buf, &start, pos);
 					gtk_text_buffer_insert_with_tags_by_name(m_buf, &start, buf, -1, "superscript", NULL);
