@@ -194,7 +194,7 @@ bool gcpReactionStep::Load (xmlNodePtr node)
 double gcpReactionStep::GetYAlign ()
 {
 	map<string, Object*>::iterator i;
-	Object *child = GetFirstChild (i);
+	GetFirstChild (i);
 	return ((*i).second)? (*i).second->GetYAlign (): 0.;
 }
 
