@@ -82,9 +82,8 @@ bool gcpReaction::Build (list<Object*>& Children) throw (invalid_argument)
 	list<Object*> Others;
 	map<double, Object*> Left, Right;
 	double x0, y0, x1, y1, x, y, xpos, ypos, l;
-	bool horiz;
+	bool horiz = true;
 	ArtDRect *rect, srect;
-	Object *cur;
 	for (i = Children.begin (); i != end; i++) {
 		// It might be better to use the objects coordinates there
 		pData->GetObjectBounds (*i, &Objects[*i]);
