@@ -85,12 +85,9 @@ void gcpTool::OnRelease(double x, double y, unsigned int state)
 	m_nState = state;
 	m_bPressed = false;
 	OnRelease();
-	double x1, y1, x2, y2;
 	if (m_pItem)
 	{
-//		gnome_canvas_item_get_bounds(GNOME_CANVAS_ITEM(m_pItem), &x1, &y1, &x2, &y2);
 		gtk_object_destroy(GTK_OBJECT(GNOME_CANVAS_ITEM(m_pItem)));
-//		gnome_canvas_request_redraw(GNOME_CANVAS(m_pWidget), (int)x1, (int)y1, (int)x2, (int)y2);
 		m_pItem = NULL;
 	}
 	m_pView->GetDoc()->FinishOperation();
