@@ -1700,7 +1700,7 @@ request_update(gpointer data)
 {
 	GnomeCanvasRichTextExt *text;
 	if (!GNOME_IS_CANVAS_RICH_TEXT_EXT (data))
-		return;
+		return TRUE;
 	text = GNOME_CANVAS_RICH_TEXT_EXT(data);
 
 	gnome_canvas_item_request_update(GNOME_CANVAS_ITEM(text));
@@ -2393,8 +2393,6 @@ gnome_canvas_rich_text_ext_export_svg (GPrintable *printable, xmlDocPtr doc, xml
 	GtkTextIter text_iter;
 	GdkRectangle rect;
 	GnomeCanvasRichTextExt *text;
-	xmlNodePtr child;
-	char *buf;
 	g_return_if_fail (GNOME_IS_CANVAS_RICH_TEXT_EXT (printable));
 	text = GNOME_CANVAS_RICH_TEXT_EXT (printable);
 	if (!text->_priv->rendered)
