@@ -77,7 +77,7 @@ bool gcpChargeTool::OnClicked()
 	if (m_Charge) {
 		if (item)
 			gnome_canvas_item_hide (item);
-		double x, y, xc, yc;
+		double x, y, xc = 0., yc;
 		m_DefaultPos = 0xff;
 		int align = ((gcpAtom*)m_pObject)->GetChargePosition(m_DefaultPos, 0., x, y);
 		if (!align) return false;
@@ -325,14 +325,13 @@ void gcpChargeTool::OnDrag()
 			}
 		}
 	} else {
-		double x, y, x1, y1, x2, y2;
+		double x, y;
 		gcpAtom *pAtom = (gcpAtom*)m_pObject;
 		if (!(m_nState & GDK_SHIFT_MASK) && (m_dDist >= m_dDistMax) && m_bChanged) {
 			gnome_canvas_item_hide (m_pItem);
 			m_bChanged = false;
 		} else if (align = pAtom->GetChargePosition (m_Pos, Angle * 180. / M_PI, x, y)) {
 			m_dAngle = Angle;
-			GtkAnchorType anchor;
 			if (m_nState & GDK_SHIFT_MASK) {
 				align = 0;
 				x = m_x0 + m_dDist * cos (m_dAngle);
@@ -380,7 +379,6 @@ void gcpChargeTool::OnRelease()
 	if (m_bChanged)
 	{
 		gcpAtom* pAtom = (gcpAtom*) m_pObject;
-		char charge = pAtom->GetCharge();
 		gcpDocument* pDoc = m_pView->GetDoc();
 		gcpOperation* pOp = pDoc-> GetNewOperation(GCP_MODIFY_OPERATION);
 		GObject *obj = G_OBJECT ((m_pObject->GetParent ()->GetType () == FragmentType)?
