@@ -28,7 +28,6 @@
 #include "plugin.h"
 #include "lib/application.h"
 #include "bondtool.h"
-#include "delocalizedtool.h"
 
 gcpBondsPlugin plugin;
 
@@ -47,5 +46,4 @@ void gcpBondsPlugin::Populate (gcpApplication* App)
 	new gcpUpBondTool (App);
 	new gcpDownBondTool (App);
 	new gcpSquiggleBondTool (App);
-	new gcpDelocalizedTool (App);
 }
