@@ -221,7 +221,7 @@ bool gcpCycleTool::OnClicked()
 						orientations.reserve(i);
 						pBond = (gcpBond*)pAtom->GetFirstBond(j);
 						orientations.push_back(pBond->GetAngle2DRad(pAtom));
-						int k;
+						unsigned k;
 						while (pBond = (gcpBond*)pAtom->GetNextBond(j))
 						{
 							k = 0;
@@ -309,7 +309,7 @@ void gcpCycleTool::OnDrag()
 			x1 = (m_x - m_xn[0]) * (m_xn[3] - m_xn[1]) + (m_xn[1] - m_y) * (m_xn[2] - m_xn[0]);
 			if (m_nState & GDK_SHIFT_MASK)
 			{
-				if (m_Chain->GetLength() == m_size - 2) return;
+				if (m_Chain->GetLength() == (unsigned) m_size - 2) return;
 				gcpBond* pBond;
 				if (pObject)
 				{
@@ -529,7 +529,6 @@ void gcpCycleTool::OnRelease()
 {
 	if (!m_size)
 		return;
-	double x1, y1, x2, y2;
 	if (m_Chain) {
 		delete m_Chain;
 		m_Chain = NULL;
