@@ -4,7 +4,7 @@
  * GChemPaint templates plugin
  * templatetree.cc 
  *
- * Copyright (C) 2004
+ * Copyright (C) 2004-2005
  *
  * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
  *
@@ -88,7 +88,6 @@ gcpTemplateTree::gcpTemplateTree(gcpApplication* App): gcpTool (App, "TemplateTr
 {
 	model = gtk_tree_store_new (NUM_COLUMNS, G_TYPE_STRING);
 	GtkTreeIter iter, child_iter;
-	TreeItem item;
 	map<string, gcpTemplate*>::iterator i, end = Templates.end();
 	string category;
 	for (i = Templates.begin(); i!= end; i++) {
@@ -145,8 +144,7 @@ void gcpTemplateTree::AddTemplate (string& key)
 	map<string, gcpTemplate*>::iterator i = Templates.find (key), end = Templates.end ();
 	GtkTreeIter iter, parent;
 	GtkTreePath *path;
-	char *s;
-	gcpTemplate *t, *t1, *new_temp = (*i).second;
+	gcpTemplate *t, *new_temp = (*i).second;
 	if (i == Templates.begin()) {
 		i++;
 		if (i == end || ((*i).second->category != new_temp->category)) {
