@@ -4,7 +4,7 @@
  * GChemPaint text plugin
  * texttool.cc 
  *
- * Copyright (C) 2002-2004
+ * Copyright (C) 2002-2005
  *
  * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
@@ -70,7 +70,6 @@ gcpTextTool::~gcpTextTool()
 
 bool gcpTextTool::OnClicked()
 {
-	void *func;
 	if (m_Active && ((m_pObject == NULL) || (m_pObject->GetType() != TextType) || (m_Active != m_pData->Items[m_pObject]->item_list->data)))
 	{
 		Unselect();
@@ -333,7 +332,7 @@ bool gcpTextTool::OnToggled(GtkWidget *btn)
 
 bool gcpTextTool::OnFont()
 {
-	GtkTextBuffer* buf ;
+	GtkTextBuffer* buf = NULL;
 	GtkTextIter start, end;
 	GtkWidget *dialog = gtk_font_selection_dialog_new("");
 	GtkToggleToolButton* BoldBtn = (GtkToggleToolButton*)m_pApp->GetToolItem("bold"),
